@@ -31,6 +31,12 @@ amqp1_opts = [
                 deprecated_group='amqp1',
                 help='Debug: dump AMQP frames to stdout'),
 
+    cfg.BoolOpt('ssl',
+                default=False,
+                help=("Attempt to connect via SSL. If no other ssl-related "
+                      "parameters are given, it will use the system's "
+                      "CA-bundle to verify the server's certificate.")),
+
     cfg.StrOpt('ssl_ca_file',
                default='',
                deprecated_group='amqp1',
@@ -54,6 +60,17 @@ amqp1_opts = [
                secret=True,
                help='Password for decrypting ssl_key_file (if encrypted)'),
 
+    cfg.BoolOpt('ssl_verify_vhost',
+                default=False,
+                help="By default SSL checks that the name in the server's"
+                " certificate matches the hostname in the transport_url. In"
+                " some configurations it may be preferable to use the virtual"
+                " hostname instead, for example if the server uses the Server"
+                " Name Indication TLS extension (rfc6066) to provide a"
+                " certificate per virtual host. Set ssl_verify_vhost to True"
+                " if the server's SSL certificate uses the virtual host name"
+                " instead of the DNS name."),
+
     cfg.BoolOpt('allow_insecure_clients',
                 default=False,
                 deprecated_group='amqp1',
@@ -77,15 +94,25 @@ amqp1_opts = [
                deprecated_group='amqp1',
                help='Name of configuration file (without .conf suffix)'),
 
+    cfg.StrOpt('sasl_default_realm',
+               default='',
+               help='SASL realm to use if no realm present in username'),
+
     cfg.StrOpt('username',
                default='',
                deprecated_group='amqp1',
+               deprecated_for_removal=True,
+               deprecated_reason='Should use configuration option '
+                                 'transport_url to provide the username.',
                help='User name for message broker authentication'),
 
     cfg.StrOpt('password',
                default='',
                deprecated_group='amqp1',
                secret=True,
+               deprecated_for_removal=True,
+               deprecated_reason='Should use configuration option '
+                                 'transport_url to provide the password.',
                help='Password for message broker authentication'),
 
     # Network connection failure retry options
@@ -156,6 +183,17 @@ amqp1_opts = [
                "'dynamic'  - use legacy addresses if the message bus does not"
                " support routing otherwise use routable addressing"),
 
+    cfg.BoolOpt('pseudo_vhost',
+                default=True,
+                help="Enable virtual host support for those message buses"
+                " that do not natively support virtual hosting (such as"
+                " qpidd). When set to true the virtual host name will be"
+                " added to all message bus addresses, effectively creating"
+                " a private 'subnet' per virtual host. Set to False if the"
+                " message bus supports virtual hosting using the 'hostname'"
+                " field in the AMQP 1.0 Open performative as the name of the"
+                " virtual host."),
+
     # Legacy addressing customization:
 
     cfg.StrOpt('server_request_prefix',
