@@ -46,27 +46,15 @@ def batch_poll_helper(func):
         driver_prefetch = in_self.prefetch_size
         if driver_prefetch > 0:
             batch_size = min(batch_size, driver_prefetch)
+        timeout = batch_timeout or timeout
 
-        with timeutils.StopWatch(timeout) as timeout_watch:
-            # poll first message
-            msg = func(in_self, timeout=timeout_watch.leftover(True))
-            if msg is not None:
-                incomings.append(msg)
-            if batch_size == 1 or msg is None:
-                return incomings
-
-            # update batch_timeout according to timeout for whole operation
-            timeout_left = timeout_watch.leftover(True)
-            if timeout_left is not None and (
-                    batch_timeout is None or timeout_left < batch_timeout):
-                batch_timeout = timeout_left
-
-        with timeutils.StopWatch(batch_timeout) as batch_timeout_watch:
-            # poll remained batch messages
-            while len(incomings) < batch_size and msg is not None:
-                msg = func(in_self, timeout=batch_timeout_watch.leftover(True))
-                if msg is not None:
-                    incomings.append(msg)
+        with timeutils.StopWatch(timeout) as watch:
+            while True:
+                message = func(in_self, timeout=watch.leftover(True))
+                if message is not None:
+                    incomings.append(message)
+                if len(incomings) == batch_size or message is None:
+                    break
 
         return incomings
     return wrapper
@@ -361,7 +349,7 @@ class BaseDriver(object):
 
     @abc.abstractmethod
     def send(self, target, ctxt, message,
-             wait_for_reply=None, timeout=None, envelope=False, retry=None):
+             wait_for_reply=None, timeout=None, retry=None):
         """Send a message to the given target and optionally wait for a reply.
         This method is used by the RPC client when sending RPC requests to a
         server.
@@ -415,7 +403,7 @@ class BaseDriver(object):
         :param target: The message's destination address
         :type target: Target
         :param ctxt: Context metadata provided by sending application which
-            must transfered along with the message.
+            is transferred along with the message.
         :type ctxt: dict
         :param message: message provided by the caller
         :type message: dict
@@ -473,7 +461,7 @@ class BaseDriver(object):
         :param target: The message's destination address
         :type target: Target
         :param ctxt: Context metadata provided by sending application which
-            must transfered along with the message.
+            is transferred along with the message.
         :type ctxt: dict
         :param message: message provided by the caller
         :type message: dict
