@@ -151,6 +151,15 @@ class RPCDispatcher(dispatcher.DispatcherBase):
         :param serializer: optional message serializer
         """
 
+        for ep in endpoints:
+            target = getattr(ep, 'target', None)
+            if target and not isinstance(target, msg_target.Target):
+                errmsg = "'target' is a reserved Endpoint attribute used" + \
+                         " for namespace and version filtering.  It must" + \
+                         " be of type oslo_messaging.Target. Do not" + \
+                         " define an Endpoint method named 'target'"
+                raise TypeError("%s: endpoint=%s" % (errmsg, ep))
+
         self.endpoints = endpoints
         self.serializer = serializer or msg_serializer.NoOpSerializer()
         self._default_target = msg_target.Target()
@@ -161,9 +170,7 @@ class RPCDispatcher(dispatcher.DispatcherBase):
                 raise TypeError('access_policy must be a subclass of '
                                 'RPCAccessPolicyBase')
         else:
-            # TODO(pvinci): Change to DefaultRPCAccessPolicy when setting to
-            # DefaultRCPAccessPolicy no longer breaks in tempest tests.
-            self.access_policy = LegacyRPCAccessPolicy()
+            self.access_policy = DefaultRPCAccessPolicy()
 
     @staticmethod
     def _is_namespace(target, namespace):
