@@ -130,11 +130,10 @@ __all__ = [
 import logging
 import sys
 
-from debtcollector.updating import updated_kwarg_default_value
-
 from oslo_messaging._i18n import _LE
 from oslo_messaging.rpc import dispatcher as rpc_dispatcher
 from oslo_messaging import server as msg_server
+from oslo_messaging import transport as msg_transport
 
 LOG = logging.getLogger(__name__)
 
@@ -142,6 +141,10 @@ LOG = logging.getLogger(__name__)
 class RPCServer(msg_server.MessageHandlingServer):
     def __init__(self, transport, target, dispatcher, executor='blocking'):
         super(RPCServer, self).__init__(transport, dispatcher, executor)
+        if not isinstance(transport, msg_transport.RPCTransport):
+            LOG.warning("Using notification transport for RPC. Please use "
+                        "get_rpc_transport to obtain an RPC transport "
+                        "instance.")
         self._target = target
 
     def _create_listener(self):
@@ -182,15 +185,6 @@ class RPCServer(msg_server.MessageHandlingServer):
                 del failure
 
 
-@updated_kwarg_default_value('access_policy', None,
-                             rpc_dispatcher.DefaultRPCAccessPolicy,
-                             message='access_policy defaults to '
-                                     'LegacyRPCAccessPolicy which '
-                                     'exposes private methods. Explicitly '
-                                     'set access_policy to '
-                                     'DefaultRPCAccessPolicy or '
-                                     'ExplicitRPCAccessPolicy.',
-                             version='?')
 def get_rpc_server(transport, target, endpoints,
                    executor='blocking', serializer=None, access_policy=None):
     """Construct an RPC server.
@@ -207,7 +201,7 @@ def get_rpc_server(transport, target, endpoints,
     :param serializer: an optional entity serializer
     :type serializer: Serializer
     :param access_policy: an optional access policy.
-           Defaults to LegacyRPCAccessPolicy
+           Defaults to DefaultRPCAccessPolicy
     :type access_policy: RPCAccessPolicyBase
     """
     dispatcher = rpc_dispatcher.RPCDispatcher(endpoints, serializer,
