@@ -30,6 +30,7 @@ import oslo_messaging
 from oslo_messaging._drivers import amqpdriver
 from oslo_messaging._drivers import common as driver_common
 from oslo_messaging._drivers import impl_rabbit as rabbit_driver
+from oslo_messaging.exceptions import MessageDeliveryFailure
 from oslo_messaging.tests import utils as test_utils
 from six.moves import mock
 
@@ -285,6 +286,20 @@ class TestRabbitPublisher(test_utils.BaseTestCase):
             try_send(e_active)
             self.assertIn('foobar', conn._declared_exchanges)
 
+    def test_send_exception_remap(self):
+        bad_exc = Exception("Non-oslo.messaging exception")
+        transport = oslo_messaging.get_transport(self.conf,
+                                                 'kombu+memory:////')
+        exchange_mock = mock.Mock()
+        with transport._driver._get_connection(
+                driver_common.PURPOSE_SEND) as pool_conn:
+            conn = pool_conn.connection
+            with mock.patch('kombu.messaging.Producer.publish',
+                            side_effect=bad_exc):
+                self.assertRaises(MessageDeliveryFailure,
+                                  conn._ensure_publishing,
+                                  conn._publish, exchange_mock, 'msg')
+
 
 class TestRabbitConsume(test_utils.BaseTestCase):
 
@@ -961,10 +976,8 @@ class RpcKombuHATestCase(test_utils.BaseTestCase):
         url = oslo_messaging.TransportURL.parse(self.conf, None)
         self.connection = rabbit_driver.Connection(self.conf, url,
                                                    driver_common.PURPOSE_SEND)
-        self.kombu_connect = mock.Mock()
         self.useFixture(fixtures.MockPatch(
-            'kombu.connection.Connection.connect',
-            side_effect=self.kombu_connect))
+            'kombu.connection.Connection.connect'))
         self.addCleanup(self.connection.close)
 
     def test_ensure_four_retry(self):
@@ -972,7 +985,6 @@ class RpcKombuHATestCase(test_utils.BaseTestCase):
         self.assertRaises(oslo_messaging.MessageDeliveryFailure,
                           self.connection.ensure, mock_callback,
                           retry=4)
-        self.assertEqual(5, self.kombu_connect.call_count)
         self.assertEqual(6, mock_callback.call_count)
 
     def test_ensure_one_retry(self):
@@ -980,7 +992,6 @@ class RpcKombuHATestCase(test_utils.BaseTestCase):
         self.assertRaises(oslo_messaging.MessageDeliveryFailure,
                           self.connection.ensure, mock_callback,
                           retry=1)
-        self.assertEqual(2, self.kombu_connect.call_count)
         self.assertEqual(3, mock_callback.call_count)
 
     def test_ensure_no_retry(self):
@@ -988,7 +999,6 @@ class RpcKombuHATestCase(test_utils.BaseTestCase):
         self.assertRaises(oslo_messaging.MessageDeliveryFailure,
                           self.connection.ensure, mock_callback,
                           retry=0)
-        self.assertEqual(1, self.kombu_connect.call_count)
         self.assertEqual(2, mock_callback.call_count)
 
 
