@@ -113,7 +113,7 @@ class CallTestCase(utils.SkipIfNoTransportURL):
 
     def test_timeout(self):
         transport = self.useFixture(
-            utils.TransportFixture(self.conf, self.url)
+            utils.RPCTransportFixture(self.conf, self.url)
         )
         target = oslo_messaging.Target(topic="no_such_topic")
         c = utils.ClientStub(transport.transport, target, timeout=1)
@@ -130,7 +130,7 @@ class CallTestCase(utils.SkipIfNoTransportURL):
 
     def test_timeout_with_concurrently_queues(self):
         transport = self.useFixture(
-            utils.TransportFixture(self.conf, self.url)
+            utils.RPCTransportFixture(self.conf, self.url)
         )
         target = oslo_messaging.Target(topic="topic_" + str(uuid.uuid4()),
                                        server="server_" + str(uuid.uuid4()))
@@ -152,6 +152,72 @@ class CallTestCase(utils.SkipIfNoTransportURL):
 
         self.assertEqual(10, server.endpoint.ival)
 
+    def test_endpoint_version_namespace(self):
+        # verify endpoint version and namespace are checked
+        target = oslo_messaging.Target(topic="topic_" + str(uuid.uuid4()),
+                                       server="server_" + str(uuid.uuid4()),
+                                       namespace="Name1",
+                                       version="7.5")
+
+        class _endpoint(object):
+            def __init__(self, target):
+                self.target = target()
+
+            def test(self, ctxt, echo):
+                return echo
+
+        transport = self.useFixture(
+            utils.RPCTransportFixture(self.conf, self.url)
+        )
+        self.useFixture(
+            utils.RpcServerFixture(self.conf, self.url, target,
+                                   executor="threading",
+                                   endpoint=_endpoint(target)))
+        client1 = utils.ClientStub(transport.transport, target,
+                                   cast=False, timeout=5)
+        self.assertEqual("Hi there", client1.test(echo="Hi there"))
+
+        # unsupported version
+        target2 = target()
+        target2.version = "7.6"
+        client2 = utils.ClientStub(transport.transport,
+                                   target2,
+                                   cast=False, timeout=5)
+        self.assertRaises(oslo_messaging.rpc.client.RemoteError,
+                          client2.test,
+                          echo="Expect failure")
+
+        # no matching namespace
+        target3 = oslo_messaging.Target(topic=target.topic,
+                                        server=target.server,
+                                        version=target.version,
+                                        namespace="Name2")
+        client3 = utils.ClientStub(transport.transport,
+                                   target3,
+                                   cast=False, timeout=5)
+        self.assertRaises(oslo_messaging.rpc.client.RemoteError,
+                          client3.test,
+                          echo="Expect failure")
+
+    def test_bad_endpoint(self):
+        # 'target' attribute is reserved and should be of type Target
+
+        class _endpoint(object):
+            def target(self, ctxt, echo):
+                return echo
+
+        target = oslo_messaging.Target(topic="topic_" + str(uuid.uuid4()),
+                                       server="server_" + str(uuid.uuid4()))
+        transport = self.useFixture(
+            utils.RPCTransportFixture(self.conf, self.url)
+        )
+        self.assertRaises(TypeError,
+                          oslo_messaging.get_rpc_server,
+                          transport=transport.transport,
+                          target=target,
+                          endpoints=[_endpoint()],
+                          executor="threading")
+
 
 class CastTestCase(utils.SkipIfNoTransportURL):
     # Note: casts return immediately, so these tests utilise a special
@@ -226,6 +292,10 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
     # to be run in parallel
 
     def test_simple(self):
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group', 'test_simple',
+                                   group='oslo_messaging_kafka')
+
         listener = self.useFixture(
             utils.NotificationFixture(self.conf, self.url, ['test_simple']))
         notifier = listener.notifier('abc')
@@ -238,6 +308,10 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
         self.assertEqual('abc', event[3])
 
     def test_multiple_topics(self):
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group', 'test_multiple_topics',
+                                   group='oslo_messaging_kafka')
+
         listener = self.useFixture(
             utils.NotificationFixture(self.conf, self.url, ['a', 'b']))
         a = listener.notifier('pub-a', topics=['a'])
@@ -290,8 +364,17 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
             self.assertThat(len(stream), matchers.GreaterThan(0))
 
     def test_independent_topics(self):
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group',
+                                   'test_independent_topics_a',
+                                   group='oslo_messaging_kafka')
         listener_a = self.useFixture(
             utils.NotificationFixture(self.conf, self.url, ['1']))
+
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group',
+                                   'test_independent_topics_b',
+                                   group='oslo_messaging_kafka')
         listener_b = self.useFixture(
             utils.NotificationFixture(self.conf, self.url, ['2']))
 
@@ -317,6 +400,10 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
         check_received(listener_b, "pub-2", b_out)
 
     def test_all_categories(self):
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group', 'test_all_categories',
+                                   group='oslo_messaging_kafka')
+
         listener = self.useFixture(utils.NotificationFixture(
             self.conf, self.url, ['test_all_categories']))
         n = listener.notifier('abc')
@@ -345,6 +432,9 @@ class NotifyTestCase(utils.SkipIfNoTransportURL):
                 # end-to-end acknowledgement with router intermediary
                 # sender pends until batch_size or timeout reached
                 self.skipTest("qdrouterd backend")
+        if self.url.startswith("kafka://"):
+            self.conf.set_override('consumer_group', 'test_simple_batch',
+                                   group='oslo_messaging_kafka')
 
         listener = self.useFixture(
             utils.BatchNotificationFixture(self.conf, self.url,
