@@ -43,8 +43,16 @@ LOG = logging.getLogger(__name__)
 _transport_opts = [
     cfg.StrOpt('transport_url',
                secret=True,
-               help='A URL representing the messaging driver to use and its '
-                    'full configuration.'),
+               help='The network address and optional user credentials for '
+                    'connecting to the messaging backend, in URL format. The '
+                    'expected format is:\n\n'
+                    'driver://[user:pass@]host:port[,[userN:passN@]hostN:'
+                    'portN]/virtual_host?query\n\n'
+                    'Example: rabbit://rabbitmq:password@127.0.0.1:5672//\n\n'
+                    'For full details on the fields in the URL see the '
+                    'documentation of oslo_messaging.TransportURL at '
+                    'https://docs.openstack.org/oslo.messaging/latest/'
+                    'reference/transport.html'),
     cfg.StrOpt('rpc_backend',
                deprecated_for_removal=True,
                deprecated_reason="Replaced by [DEFAULT]/transport_url",
@@ -153,6 +161,20 @@ class Transport(object):
         self._driver.cleanup()
 
 
+class RPCTransport(Transport):
+    """Transport object for RPC."""
+
+    def __init__(self, driver):
+        super(RPCTransport, self).__init__(driver)
+
+
+class NotificationTransport(Transport):
+    """Transport object for notifications."""
+
+    def __init__(self, driver):
+        super(NotificationTransport, self).__init__(driver)
+
+
 class InvalidTransportURL(exceptions.MessagingException):
     """Raised if transport URL is invalid."""
 
@@ -171,7 +193,8 @@ class DriverLoadFailure(exceptions.MessagingException):
         self.ex = ex
 
 
-def _get_transport(conf, url=None, allowed_remote_exmods=None, aliases=None):
+def _get_transport(conf, url=None, allowed_remote_exmods=None, aliases=None,
+                   transport_cls=RPCTransport):
     allowed_remote_exmods = allowed_remote_exmods or []
     conf.register_opts(_transport_opts)
 
@@ -190,7 +213,7 @@ def _get_transport(conf, url=None, allowed_remote_exmods=None, aliases=None):
     except RuntimeError as ex:
         raise DriverLoadFailure(url.transport, ex)
 
-    return Transport(mgr.driver)
+    return transport_cls(mgr.driver)
 
 
 @removals.remove(
@@ -229,7 +252,8 @@ def get_transport(conf, url=None, allowed_remote_exmods=None, aliases=None):
     :type aliases: dict
     """
     return _get_transport(conf, url,
-                          allowed_remote_exmods, aliases)
+                          allowed_remote_exmods, aliases,
+                          transport_cls=RPCTransport)
 
 
 class TransportHost(object):
@@ -267,11 +291,11 @@ class TransportURL(object):
 
     Transport URLs take the form::
 
-      scheme://[user:pass@]host:port[,[userN:passN@]hostN:portN]/virtual_host?query
+      driver://[user:pass@]host:port[,[userN:passN@]hostN:portN]/virtual_host?query
 
     where:
 
-    scheme
+    driver
       Specifies the transport driver to use. Typically this is `rabbit` for the
       RabbitMQ broker. See the documentation for other available transport
       drivers.
